Flux Balance Analysis
======================

The *PyFBA.fba* modules include code for developing the stoichiometric matrix, adding reaction bounds and compound
bounds, identifying reactions involved in uptake and secretion, and running the FBA.


Methods associated with creating the stoichiometric matrix
-----------------------------------------------------------

.. automodule:: PyFBA.fba.create_stoichiometric_matrix
    :members:

Adding the limits to the reactions and compounds
------------------------------------------------

.. automodule:: PyFBA.fba.bounds
    :members:

Identifying the reactions that are uptake and secretion reactions
-----------------------------------------------------------------

.. automodule:: PyFBA.fba.external_reactions
    :members:

Running the FBA and retrieving the results
------------------------------------------

.. automodule:: PyFBA.fba.run_fba
    :members: